Commit 63b3b9a5582e7936af0f79bd602db1400e155d42

Simon McVittie 2022-06-13T16:02:40

Fix some typos in diagnostic messages Detected by Debian's packaging QA tool, Lintian. Signed-off-by: Simon McVittie <smcv@collabora.com>

diff --git a/src/video/x11/SDL_x11window.c b/src/video/x11/SDL_x11window.c
index 6a1e299..f7ec281 100644
--- a/src/video/x11/SDL_x11window.c
+++ b/src/video/x11/SDL_x11window.c
@@ -1827,7 +1827,7 @@ int SDL_X11_SetWindowTitle(Display* display, Window xwindow, char* title) {
     } else if (conv < 0) {
         return SDL_OutOfMemory();
     } else { /* conv > 0 */
-        SDL_LogDebug(SDL_LOG_CATEGORY_VIDEO, "%d characters were not convertable to the current locale!", conv);
+        SDL_LogDebug(SDL_LOG_CATEGORY_VIDEO, "%d characters were not convertible to the current locale!", conv);
         return 0;
     }
 
diff --git a/test/testautomation_platform.c b/test/testautomation_platform.c
index 0a31ad8..5eb37b3 100644
--- a/test/testautomation_platform.c
+++ b/test/testautomation_platform.c
@@ -544,7 +544,7 @@ static const SDLTest_TestCaseReference platformTest1 =
         { (SDLTest_TestCaseFp)platform_testTypes, "platform_testTypes", "Tests predefined types", TEST_ENABLED};
 
 static const SDLTest_TestCaseReference platformTest2 =
-        { (SDLTest_TestCaseFp)platform_testEndianessAndSwap, "platform_testEndianessAndSwap", "Tests endianess and swap functions", TEST_ENABLED};
+        { (SDLTest_TestCaseFp)platform_testEndianessAndSwap, "platform_testEndianessAndSwap", "Tests endianness and swap functions", TEST_ENABLED};
 
 static const SDLTest_TestCaseReference platformTest3 =
         { (SDLTest_TestCaseFp)platform_testGetFunctions, "platform_testGetFunctions", "Tests various SDL_GetXYZ functions", TEST_ENABLED};
diff --git a/test/testguid.c b/test/testguid.c
index 3b2b90f..29ccb6a 100644
--- a/test/testguid.c
+++ b/test/testguid.c
@@ -144,7 +144,7 @@ TestGuidToString(void)
                 ++written_size;
             }
             if (!ASSERT_EQ("Output length is within expected bounds", 1, written_size <= size)) {
-                SDL_Log("  with lenght %d: wrote %d of %d permitted bytes",
+                SDL_Log("  with length %d: wrote %d of %d permitted bytes",
                         size, written_size, size);
             }
             if (size >= 33) {
diff --git a/src/video/kmsdrm/SDL_kmsdrmvulkan.c b/src/video/kmsdrm/SDL_kmsdrmvulkan.c
index b9ab13c..d404fd8 100644
--- a/src/video/kmsdrm/SDL_kmsdrmvulkan.c
+++ b/src/video/kmsdrm/SDL_kmsdrmvulkan.c
@@ -476,9 +476,9 @@ SDL_bool KMSDRM_Vulkan_CreateSurface(_THIS,
         }
     }
 
     /* If we couldn't find an appropiate plane, error out. */
     if (plane == UINT32_MAX) {
-        SDL_SetError("Vulkan couldn't find an appropiate plane.");
+        SDL_SetError("Vulkan couldn't find an appropriate plane.");
         goto clean;
     }
 
@@ -476,9 +476,9 @@ SDL_bool KMSDRM_Vulkan_CreateSurface(_THIS,
     }
 
-    /* If we couldn't find an appropiate plane, error out. */
+    /* If we couldn't find an appropriate plane, error out. */
     if (plane == UINT32_MAX) {